@@ -134,6 +134,10 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #define PPM_CL_ACTIVE (1 << 19)			/* libsinsp-specific flag. Set in the first non-clone event for
 										   this thread. */
 #define PPM_CL_CLONE_NEWUSER (1 << 20)
+#define PPM_CL_PIPE_SRC (1 << 21)			/* libsinsp-specific flag. Set if this thread has been 
+										       detected to be the source in a shell pipe. */
+#define PPM_CL_PIPE_DST (1 << 22)			/* libsinsp-specific flag. Set if this thread has been 
+										       detected to be the destination in a shell pipe. */
 
 /*
  * Futex Operations
@@ -587,6 +591,7 @@ enum ppm_event_type {
 	PPME_SYSCALL_CHDIR_X = 95,
 	PPME_SYSCALL_FCHDIR_E = 96,
 	PPME_SYSCALL_FCHDIR_X = 97,
+	/* mkdir/rmdir events are not emitted anymore */
 	PPME_SYSCALL_MKDIR_E = 98,
 	PPME_SYSCALL_MKDIR_X = 99,
 	PPME_SYSCALL_RMDIR_E = 100,
@@ -763,7 +768,19 @@ enum ppm_event_type {
 	PPME_MESOS_X = 271,
 	PPME_CONTAINER_JSON_E = 272,
 	PPME_CONTAINER_JSON_X = 273,
-	PPM_EVENT_MAX = 274
+	PPME_SYSCALL_SETSID_E = 274,
+	PPME_SYSCALL_SETSID_X = 275,
+	PPME_SYSCALL_MKDIR_2_E = 276,
+	PPME_SYSCALL_MKDIR_2_X = 277,
+	PPME_SYSCALL_RMDIR_2_E = 278,
+	PPME_SYSCALL_RMDIR_2_X = 279,
+	PPME_NOTIFICATION_E = 280,
+	PPME_NOTIFICATION_X = 281,
+	PPME_SYSCALL_EXECVE_17_E = 282,
+	PPME_SYSCALL_EXECVE_17_X = 283,
+	PPME_SYSCALL_UNSHARE_E = 284,
+	PPME_SYSCALL_UNSHARE_X = 285,
+	PPM_EVENT_MAX = 286
 };
 /*@}*/
 
@@ -1126,6 +1143,7 @@ enum ppm_event_flags {
 	EF_WAITS = (1 << 7), /* This event reads data from an FD. */
 	EF_SKIPPARSERESET = (1 << 8), /* This event shouldn't pollute the parser lastevent state tracker. */
 	EF_OLD_VERSION = (1 << 9), /* This event is kept for backward compatibility */
+	EF_DROP_FALCO = (1 << 10) /* This event should not be passed up to Falco */
 };
 
 /*
@@ -1260,14 +1278,8 @@ struct ppm_evt_hdr {
 #define PPM_IOCTL_DISABLE_SIGNAL_DELIVER _IO(PPM_IOCTL_MAGIC, 14)
 #define PPM_IOCTL_ENABLE_SIGNAL_DELIVER _IO(PPM_IOCTL_MAGIC, 15)
 #define PPM_IOCTL_GET_PROCLIST _IO(PPM_IOCTL_MAGIC, 16)
+#define PPM_IOCTL_SET_TRACERS_CAPTURE _IO(PPM_IOCTL_MAGIC, 17)
 
-/*!
-  \brief System call description struct.
-*/
-struct ppm_syscall_desc {
-	enum ppm_event_category category; /**< System call category. */
-	char *name; /**< System call name, e.g. 'open'. */
-};
 
 extern const struct ppm_name_value socket_families[];
 extern const struct ppm_name_value file_flags[];
